function [RES]=Classic_CASEA_Uniform(NAFEMS_Data,Sizesample)
 %INPUT
 % D Data Structure
 
% Solve The NAFEMS CHALLENGE PROBLEM CASE A: 3 Interval sources have been given, one for each parameter of interest (R,L,C)
% ASSUMING UNIFORM DISTRIBUTION (Laplace's Principia of indifference)
% And Compute Reliability w.r.t. 3 requirements
%1) Vc(10ms)>0.9
%2) Vc(t=tr)>0.9 and tr<8ms
%3) Z>=1
%% INPUTS
% a(1)=40;b(1)=1000;  % R Source 1
% c(1)=1*10^-3;d(1)=10*10^-3;     % L Source 1
% e(1)=1*10^-6;f(1)=10*10^-6;     % C Source 1
% interval asignement
a=NAFEMS_Data.CASEAB_RminS(1) ;b=NAFEMS_Data.CASEAB_RmaxS(1);
c=NAFEMS_Data.CASEAB_LminS(1) ;d=NAFEMS_Data.CASEAB_LmaxS(1);
e=NAFEMS_Data.CASEAB_CminS(1) ;f=NAFEMS_Data.CASEAB_CmaxS(1); 
 %% SAMPLES FOR THE MONTE CARLO
 %Sizesample=10^5; % samples number 
%% OUTPUTS
%  RES.PVc10 = probability of fail requirement on voltage at the capacitor
%  RES.Ptr = probability of fail requirement on the rise time
%  RES.Pz = probability of fail requirement on the damping factor

%% MONTE CARLO SAMPLING
% set the unfiorm distribution parameters
A=a(1);B=b(1);C=c(1);D=d(1);E=e(1);F=f(1); 
% sample parameters
R = A + rand(Sizesample,1).*(B-A);
L = C + rand(Sizesample,1).*(D-C);
C = E + rand(Sizesample,1).*(F-E); 
%% COMPUTE Z
Zeta=0.5*R.*((C./L).^0.5); 
% eliminate underdumped samples
R(Zeta<1)=[];
L(Zeta<1)=[];
C(Zeta<1)=[];
%%  System Solver
%Compute S1 and S2 to solve system
S1=sqrt((R./(2*L)).^2-1./(L.*C))-R./(2*L);
S2=-sqrt((R./(2*L)).^2-1./(L.*C))-R./(2*L);
A1=S2./(S1-S2);
A2=S1./(S2-S1);
Vc10=repmat(A1,1,length(0.01)).*exp(S1*0.01)+repmat(A2,1,length(0.01)).*exp(S2*0.01)+1;
Vctr=repmat(A1,1,length(0.008)).*exp(S1*0.008)+repmat(A2,1,length(0.008)).*exp(S2*0.08)+1;
%Vc08 = my_fun_Vc08(R,L,C);
%Vc10 = my_fun_Vc10(R,L,C);   
%% SAVE RESULTS
RES.Vc10=Vc10;
RES.Vc08=Vctr;
RES.Z=Zeta;
% failure probability
RES.PVc10=sum(Vc10<=0.9)/(Sizesample-sum(Zeta<1));
RES.Ptr=sum(Vctr<=0.9)/(Sizesample-sum(Zeta<1));
RES.Pz=sum(Zeta<1)/Sizesample;

end